/*
This sketch illustrates ideas from the course "2D Animation and Interaction"
available at www.imaginary-institute.com, and my book "Processing for
Artists and Designers," published by AK Peters. For more of my Processing
programs, visit www.glassner.com or www.imaginary-institute.com
---
Draw a never-ending series of random flower gardens, based on the wonderful
DePatie-Freleng style of animation.
---
Andrew Glassner, version 2, April 2014
*/
void setup() {
  size(800, 400);
  smooth();
  frameRate(.5);  // draw a new frame every 2 seconds
}
// draw a little garden containing 20 to 40 flowers
void draw() {
  background(165, 240, 225);  // light sky blue
  int numFlowers = (int)random(20, 30);
  for (int i=0; i<numFlowers; i++) drawOneDaisy();
  // Make a green hill for them to sit on. It's a circle that passes
  // through the two bottom corners, and rises h pixels above the bottom
  float h = height/8.0;              // vertical extent of the circle
  float r = ((h*h)+(width*width/4.0))/(2*h);  // Thanks, Pythagoras!
  fill(30, 125, 55);                 // dark green
  ellipse(width/2.0, height+r-h, 2*r, 2*r); // the hillside
}
void drawOneDaisy() {
  float cx = width * random(0, 1);           // the flower's horizontal center
  float cy = height * random(.2, .8);        // the flower's vertical center
  float r = (width/2.0) * random(.075, .14); // the outer radius of the petals
  float innerR = r * 0.2;                    // radius of the central bud
  int numPetals = (int)random(4, 20);        // draw this many petals
  // Pick a couple of bright colors.  Using HSB, we can keep the
  // saturation and brightness high, while choosing a random hue.
  colorMode(HSB);
  color insideColor = color(random(0, 255), random(100, 255), random(100, 200));
  color petalsColor = color(random(0, 255), random(100, 255), random(100, 200));
  colorMode(RGB);
  // Draw a slanted stalk from the center of the bud to the ground.
  noFill();
  stroke(0);
  line(cx, cy, cx+random(-50, 50), height);
  // draw each petal
  noStroke();
  fill(petalsColor);
  // pick a random starting angle for the petals
  float angleStart = random(TWO_PI);
  // find the maximum angle spanned by each petal
  float angleSize = TWO_PI/numPetals;
  for (int i=0; i<numPetals; i++) {
    // make the range of angles spanned by this petal
    float angle1 = angleStart + (angleSize * (i+random(.1, .4)));
    float angle2 = angleStart + (angleSize * (i+random(.6, .9)));
    // make the outermost radius of this petal
    float thisR = r * random(.9, 1.1);
    // draw the petal as a filled-in arc radiating from the bud
    arc(cx, cy, thisR*2, thisR*2, angle1, angle2);
  }
  // draw the central bud
  fill(insideColor);
  noStroke();
  ellipse(cx, cy, innerR*2, innerR*2);
}
